@@ -8,15 +8,15 @@ package Tangence::Object;
 use strict;
 use warnings;
 
-our $VERSION = '0.08';
+our $VERSION = '0.09';
 
 use Carp;
 
 use Tangence::Constants;
 
-use Tangence::Meta::Class;
+use Tangence::Class;
 
-Tangence::Meta::Class->declare(
+Tangence::Class->declare(
    __PACKAGE__,
 
    events => {
@@ -53,7 +53,7 @@ sub new
    my $self = bless {
       id => $id,
       registry => $registry,
-      meta => $args{meta} || Tangence::Meta::Class->for_perlname( $class ),
+      meta => $args{meta} || Tangence::Class->for_perlname( $class ),
 
       event_subs => {},   # {$event} => [ @cbs ]
 
@@ -214,7 +214,7 @@ sub smash
 sub _meta
 {
    my $self = shift;
-   return ref $self ? $self->{meta} : Tangence::Meta::Class->for_perlname( $self );
+   return ref $self ? $self->{meta} : Tangence::Class->for_perlname( $self );
 }
 
 sub can_method
