@@ -9,17 +9,18 @@ use strict;
 use warnings;
 use base qw( Tangence::Object );
 
-our $VERSION = '0.08';
+our $VERSION = '0.09';
 
 use Carp;
 
 use Tangence::Constants;
+use Tangence::Class;
 
 use Tangence::Compiler::Parser;
 
 use Scalar::Util qw( weaken );
 
-Tangence::Meta::Class->declare(
+Tangence::Class->declare(
    __PACKAGE__,
 
    methods => {
@@ -84,7 +85,7 @@ sub new
    my $self = $class->SUPER::new(
       id => $id,
       registry => "BOOTSTRAP",
-      meta => Tangence::Meta::Class->for_perlname( $class ),
+      meta => Tangence::Class->for_perlname( $class ),
    );
    weaken( $self->{registry} = $self );
    
@@ -185,18 +186,10 @@ package # hide from CPAN
    Tangence::Registry::Parser;
 use base qw( Tangence::Compiler::Parser );
 
-use Tangence::Meta::Property;
-
 sub make_class
 {
    my $self = shift;
-   return Tangence::Meta::Class->new( @_ );
-}
-
-sub make_property
-{
-   my $self = shift;
-   return Tangence::Meta::Property->new( @_ );
+   return Tangence::Class->new( @_ );
 }
 
 =head1 AUTHOR
